@@ -2,7 +2,7 @@ package Bio::DB::HTS::Kseq::Record;
 
 =head1 LICENSE
 
-Copyright [1999-2016] EMBL-European Bioinformatics Institute
+Copyright [2015-2018] EMBL-European Bioinformatics Institute
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
@@ -53,7 +53,10 @@ The quality string from a FASTA/Q record
 
 =cut
 
-$Bio::DB::HTS::Kseq::Record::VERSION = '2.0';
+use strict;
+use warnings;
+
+$Bio::DB::HTS::Kseq::Record::VERSION = '2.10';
 
 sub name {
   return $_[0]->{name};
